@@ -20,7 +20,7 @@ package MongoDB::Code;
 # ABSTRACT: JavaScript Code
 
 use version;
-our $VERSION = 'v0.703.4'; # TRIAL
+our $VERSION = 'v0.703.5'; # TRIAL
 
 #pod =head1 NAME
 #pod
@@ -29,6 +29,7 @@ our $VERSION = 'v0.703.4'; # TRIAL
 #pod =cut
 
 use Moose;
+use namespace::clean -except => 'meta';
 
 #pod =head1 ATTRIBUTES
 #pod
@@ -56,19 +57,23 @@ has scope => (
     required => 0,
 );
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MongoDB::Code - JavaScript Code
 
 =head1 VERSION
 
-version v0.703.4
+version v0.703.5
 
 =head1 NAME
 
