@@ -20,12 +20,13 @@ package MongoDB::GridFS;
 # ABSTRACT: A file storage utility
 
 use version;
-our $VERSION = 'v0.703.4'; # TRIAL
+our $VERSION = 'v0.703.5'; # TRIAL
 
-use Moose;
 use MongoDB::GridFS::File;
 use DateTime 0.78; # drops dependency on bug-prone Math::Round
 use Digest::MD5;
+use Moose;
+use namespace::clean -except => 'meta';
 
 #pod =head1 NAME
 #pod
@@ -121,11 +122,11 @@ sub _build_chunks {
 sub BUILD {
     my ($self) = @_;
    
-    # check for the required indexs in the system.indexes colleciton
+    # check for the required indexes in the system.indexes collection
     my $count = $self->_database->get_collection('system.indexes')->count({key=>{filename => 1}});
     $count   += $self->_database->get_collection('system.indexes')->count({key=>{files_id => 1, n => 1}});
     
-    # if we dont have the required indexes, create them now.
+    # if we don't have the required indexes, create them now.
     if ($count < 2){
        $self->_ensure_indexes();
     }
@@ -360,10 +361,10 @@ sub _calc_md5 {
     my $result = $self->_database->run_command(["filemd5", $id, "root" => $self->prefix]);
     
     # If we didn't get a hash back, it means something is wrong (probably to do with gridfs's 
-    # indexes because its currently the only error that is thown from the md5 class)
+    # indexes because its currently the only error that is thrown from the md5 class)
     if (ref($result) ne 'HASH') {
         # Yep, indexes are missing. If we have the $retry flag, lets create them calc the md5 again
-        # but we wont pass set the $retry flag again. we dont want an infinate loop for any reason. 
+        # but we wont pass set the $retry flag again. We don't want an infinite loop for any reason. 
         if ($retry == 1 && $result eq 'need an index on { files_id : 1 , n : 1 }'){
             $self->_ensure_indexes();
             $result = $self->_calc_md5($id, $root, 0);
@@ -416,19 +417,23 @@ sub all {
     return @ret;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MongoDB::GridFS - A file storage utility
 
 =head1 VERSION
 
-version v0.703.4
+version v0.703.5
 
 =head1 SYNOPSIS
 
