@@ -19,10 +19,8 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server
 
 use version;
-our $VERSION = 'v0.703.4'; # TRIAL
+our $VERSION = 'v0.703.5'; # TRIAL
 
-use Moose;
-use Moose::Util::TypeConstraints;
 use MongoDB;
 use MongoDB::Cursor;
 use MongoDB::BSON::Binary;
@@ -34,6 +32,9 @@ use Scalar::Util 'reftype';
 use boolean;
 use Encode;
 use Try::Tiny;
+use Moose;
+use MongoDB::_Types;
+use namespace::clean -except => 'meta';
 
 use constant {
     PRIMARY             => 0, 
@@ -170,6 +171,21 @@ has max_bson_size => (
     default  => 4194304
 );
 
+has _max_bson_wire_size => (
+    is       => 'rw',
+    isa      => 'Int',
+    required => 1,
+    default  => 16_793_600, # 16MiB + 16KiB
+);
+
+# XXX eventually, get this off an isMaster call
+has _max_write_batch_size => (
+    is       => 'rw',
+    isa      => 'Int',
+    required => 1,
+    default  => 1000,
+);
+
 has find_master => (
     is       => 'ro',
     isa      => 'Bool',
@@ -207,7 +223,7 @@ has sasl => (
 
 has sasl_mechanism => ( 
     is       => 'ro',
-    isa      => subtype( Str => where { /^GSSAPI|PLAIN$/ } ),
+    isa      => 'SASLMech',
     required => 1,
     default  => 'GSSAPI',
 );
@@ -286,7 +302,7 @@ has _use_write_cmd => (
 
 sub BUILD {
     my ($self, $opts) = @_;
-    eval "use ${_}" # no Any::Moose::load_class becase the namespaces already have symbols from the xs bootstrap
+    eval "use ${_}" # no Any::Moose::load_class because the namespaces already have symbols from the xs bootstrap
         for qw/MongoDB::Database MongoDB::Cursor MongoDB::OID MongoDB::Timestamp/;
 
     my @pairs;
@@ -392,11 +408,16 @@ sub BUILD {
 
 sub _build__use_write_cmd { 
     my $self = shift;
-    
+
     # find out if we support write commands
-    my $result = $self->get_database( "test" )->run_command( { insert => "test", documents => [ ] } );
-    
-    return 1 if ref $result && $result->{ok} == 1;
+    my $result = eval {
+        $self->get_database( $self->db_name )->_try_run_command( { "ismaster" => 1 } );
+    };
+
+    my $max_wire_version = ($result && exists $result->{maxWireVersion} )
+        ? $result->{maxWireVersion} : 0;
+
+    return 1 if $max_wire_version > 1;
     return 0;
 }
 
@@ -880,6 +901,16 @@ sub _check_wire_version {
 
 }
 
+sub _write_concern {
+    my ($self) = @_;
+    my $wc = {
+        w => $self->w,
+        wtimeout => $self->wtimeout,
+    };
+    $wc->{j} = $self->j if $self->j;
+    return $wc;
+}
+
 __PACKAGE__->meta->make_immutable( inline_destructor => 0 );
 
 1;
@@ -888,13 +919,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MongoDB::MongoClient - A connection to a MongoDB server
 
 =head1 VERSION
 
-version v0.703.4
+version v0.703.5
 
 =head1 SYNOPSIS
 
@@ -973,7 +1006,7 @@ number for more replicas.
 In MongoDB v2.0+, you can "tag" replica members. With "tagging" you can specify a 
 new "getLastErrorMode" where you can create new
 rules on how your data is replicated. To used you getLastErrorMode, you pass in the 
-name of the mode to the C<w> parameter. For more infomation see: 
+name of the mode to the C<w> parameter. For more information see: 
 http://www.mongodb.org/display/DOCS/Data+Center+Awareness
 
 =head2 wtimeout
@@ -1277,8 +1310,8 @@ with the server, and therefore should not generally be called by client code.
 
 =head1 MULTITHREADING
 
-Cloning instances of this class is disabled in Perl 5.8.7+, so forked threads
-will have to create their own connections to the database.
+Existing connections are closed when a thread is created.  If C<auto_reconnect>
+is true, then connections will be re-established as needed.
 
 =head1 SEE ALSO
 
