@@ -19,9 +19,10 @@ package MongoDB::OID;
 # ABSTRACT: A Mongo Object ID
 
 use version;
-our $VERSION = 'v0.703.4'; # TRIAL
+our $VERSION = 'v0.703.5'; # TRIAL
 
 use Moose;
+use namespace::clean -except => 'meta';
 
 #pod =head1 NAME
 #pod
@@ -34,7 +35,7 @@ use Moose;
 #pod
 #pod     my $id = $collection->insert({'name' => 'Alice', age => 20});
 #pod
-#pod C<$id> will be a C<MongoDB::OID> that can be used to retreive or update the 
+#pod C<$id> will be a C<MongoDB::OID> that can be used to retrieve or update the 
 #pod saved document:
 #pod
 #pod     $collection->update({_id => $id}, {'age' => {'$inc' => 1}});
@@ -122,6 +123,13 @@ sub get_time {
     return hex(substr($self->value, 0, 8));
 }
 
+# for testing purposes
+sub _get_pid {
+    my ($self) = @_;
+
+    return hex(substr($self->value, 14, 4));
+}
+
 #pod =head2 TO_JSON
 #pod
 #pod     my $json = JSON->new;
@@ -155,13 +163,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MongoDB::OID - A Mongo Object ID
 
 =head1 VERSION
 
-version v0.703.4
+version v0.703.5
 
 =head1 SYNOPSIS
 
@@ -170,7 +180,7 @@ C<_id> field will be added with a new C<MongoDB::OID> as its value.
 
     my $id = $collection->insert({'name' => 'Alice', age => 20});
 
-C<$id> will be a C<MongoDB::OID> that can be used to retreive or update the 
+C<$id> will be a C<MongoDB::OID> that can be used to retrieve or update the 
 saved document:
 
     $collection->update({_id => $id}, {'age' => {'$inc' => 1}});
